@@ -26,7 +26,6 @@
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
-#include <Lum/Model/Time.h>
 
 class DataInput : public Lum::Component
 {
@@ -35,11 +34,7 @@ private:
   Lum::Model::ActionRef              todayAction;
   Lum::Model::ActionRef              nextDayAction;
 
-  Lum::Model::ActionRef              addFoodAction;
-  Lum::Model::ActionRef              removeFoodAction;
-  Lum::Model::ActionRef              editFoodAction;
-  Lum::Model::ActionRef              registerFoodAction;
-
+  //Lum::Model::ActionRef              addFoodAction;
   Lum::Model::ActionRef              addWeightAction;
   Lum::Model::ActionRef              removeItemAction;
   Lum::Model::ActionRef              editItemAction;
@@ -47,38 +42,26 @@ private:
   Lum::Model::StringRef              foodSearch;
   Lum::Model::StringRef              averageDiff;
   Lum::Model::StringRef              summary;
-  Lum::Model::TimeRef                time;
-  Lum::Model::ListTableRef           foods;
   Lum::Model::ListTableRef           entries;
-  Lum::Model::SingleLineSelectionRef foodSelection;
   Lum::Model::SingleLineSelectionRef entrySelection;
-  std::wstring                       lastFoodSearchFilter;
-  Lum::Model::ActionRef              searchTimerAction;
   Lum::Model::IntRef                 trend;
 
 private:
   void UpdateEntries();
   void UpdateSummary();
 
-  void AddFood();
-  void EditFood();
-  void RemoveFood();
-  void RegisterFood();
-
   void AddWeight();
   void RemoveItem();
   void EditItem();
 
 public:
   DataInput();
-  ~DataInput();
 
   void CalcSize();
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 
   void InitializeGUI();
-  void UpdateFoods();
 };
 
 #endif
