@@ -26,10 +26,8 @@
 #include <Lum/DateSelect.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
-#include <Lum/TextValue.h>
 #include <Lum/TimeSelect.h>
 
 #include <Lum/Base/String.h>
@@ -260,7 +258,7 @@ FoodInput::FoodInput()
    registerFoodAction(new Lum::Model::Action()),
 
    foodSearch(new Lum::Model::String(L"")),
-   foods(new Lum::Model::ListTable(3)),
+   foods(new Lum::Model::ListTable()),
    foodSelection(new Lum::Model::SingleLineSelection()),
 
    searchTimerAction(new Lum::Model::Action())
@@ -285,24 +283,17 @@ void FoodInput::CalcSize()
   Lum::Panel            *sb;
   Lum::Panel            *horiz;
   Lum::Panel            *vert;
-  Lum::String           *string;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
   // Search box
 
-  sb=new Lum::VPanel();
-  sb->SetFlex(true,false);
-
-  string=new Lum::String();
-  string->SetFlex(true,false);
-  string->SetModel(foodSearch);
-  sb->Add(string);
+  sb=Lum::VPanel::Create(true,false);
+  sb->Add(Lum::String::Create(foodSearch,true,false));
 
   // Food table
 
-  ft=new Lum::HPanel();
-  ft->SetFlex(true,true);
+  ft=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
   headerModel->AddColumn(_(L"FOOD_TABLE_HEADER_FOOD",L"Food"),Lum::Base::Size::stdCharWidth,20,true);
@@ -329,13 +320,12 @@ void FoodInput::CalcSize()
 
   // Layout comonents
 
-  horiz=new Lum::HPanel();
+  horiz=Lum::HPanel::Create();
 
-  vert=new Lum::VPanel();
-  vert->SetFlex(true,true);
+  vert=Lum::VPanel::Create(true,true);
 
   vert->Add(sb);
-  vert->Add(new Lum::VSpace());
+  vert->AddSpace();
   vert->Add(ft);
 
   horiz->Add(vert);
